/*! Tripetto Collector 0.4.26-26 - Copyright (C) 2018 Tripetto B.V. - All Rights Reserved */

declare module "@marblecore/l10n" {
    /** Explicit exports */
    export { Domain, IDomain, ITranslation } from "@marblecore/l10n/lib/domain";
    export {
        DEFAULTS as LOCALE_DEFAULTS,
        ILocale,
        Locales
    } from "@marblecore/l10n/lib/locales";
    export {
        gettext,
        dgettext,
        ngettext,
        dngettext,
        pgettext,
        dpgettext,
        npgettext,
        dnpgettext,
        _,
        _n
    } from "@marblecore/l10n/lib/l10n";
}

declare module "@marblecore/l10n/lib/domain" {
    export interface IDomain {
        /** Specifies the locale (language[_territory]). */
        readonly locale: string;
        /** Specifies the language in english. */
        readonly language: string;
        /** Specifies the language in the native language. */
        readonly native: string;
    }
    export interface ITranslation {
        /** Retrieves the specified translation strings. */
        [msg: string]: string[];
    }
    export class Domain {
        /**
         * Verifies if the specified domain is loaded.
         * @param sDomain Specifies the language domain identifier.
         */
        static isLoaded(sDomain: string): boolean;
        /** Retrieves a list of loaded domains. */
        static readonly domains: string[];
        /** Sets the default domain. */
        static default: string;
        /**
         * Loads translation domains.
         * @param pTranslation Specifies the translation domains.
         * @param bSelect Specifies if the translation domain should be selected.
         * @param bReplace Specifies if the translation domain needs to be replaced when it already exists (instead of enriched).
         * @return Returns `true` if the domain is loaded.
         */
        static load(
            pTranslation: ITranslation | ITranslation[],
            bSelect?: boolean,
            bReplace?: boolean
        ): boolean;
        /**
         * Translates the specified message.
         * @param sDomain Specifies the language domain identifier.
         * @param sContext Specifies the context of the message.
         * @param sId Specifies the message identifier or string to translate.
         * @param nCount Specifies the count for the plural.
         * @param bPlural Specifies if the message is a plural string.
         * @param sPluralId Specifies the plural message identifier or string to translate.
         * @param pArguments Specifies an array with string arguments which can be referenced in the context string using the percent sign
         * followed by the argument index `%n`. The first argument is referenced with `%1`.
         * @return Returns the formatted string.
         */
        static translate(
            sDomain: string,
            sContext: string,
            sId: string,
            bPlural?: boolean,
            sPluralId?: string,
            nCount?: number,
            ...pArguments: string[]
        ): string;
        /**
         * Constructs a new domain.
         * @param pTranslation Reference to the translation data.
         */
        constructor(pTranslation: ITranslation);
        /** Retrieves the number of plurals. */
        readonly plurals: number;
        /**
         * Retrieves the plural index for the supplied count.
         * @param nCount Specifies the count.
         * @return Returns the plural index.
         */
        plural(nCount: number): number;
        /**
         * Retrieves the translation for the specified message identifier or string.
         * @param sId Specifies the message identifier or string to retrieve.
         * @return Returns an array with translation strings.
         */
        translation(sId: string): string[];
    }
}

declare module "@marblecore/l10n/lib/locales" {
    import { IDomain } from "@marblecore/l10n/lib/domain";
    /** Describes a locale string. */
    export interface ILocaleString {
        readonly full: string;
        readonly long: string;
        readonly medium: string;
        readonly short: string;
    }
    /**
     * Describes the locale formats.
     * @param T Specifies the formatting type.
     */
    export interface ILocaleFormatting<T> {
        readonly formatted: T;
        readonly nominative: T;
    }
    /** Describes a locale number. */
    export interface ILocaleNumber {
        readonly decimals: string;
        readonly grouping: string;
        readonly minus: string;
    }
    /** Describes the locale months. */
    export interface ILocaleMonths {
        readonly abbreviated: string[];
        readonly narrow: string[];
        readonly wide: string[];
    }
    /** Describes the locale days. */
    export interface ILocaleDays {
        readonly abbreviated: string[];
        readonly narrow: string[];
        readonly short: string[];
        readonly wide: string[];
    }
    /** Describes the locale time. */
    export interface ILocaleTime {
        readonly AM: string;
        readonly PM: string;
    }
    /** Describes the locale translations. */
    export interface ILocaleTranslations {
        readonly months: ILocaleFormatting<ILocaleMonths>;
        readonly days: ILocaleFormatting<ILocaleDays>;
        readonly time: ILocaleTime;
    }
    /**  Describes the locale formats. */
    export interface ILocaleFormats {
        readonly date: ILocaleString;
        readonly time: ILocaleString;
        readonly dateTime: ILocaleString;
        readonly numbers: ILocaleNumber;
    }
    /**  Describes a locale. */
    export interface ILocale {
        readonly locale: string;
        readonly domain: string;
        readonly countryCode: string;
        readonly country: string;
        readonly countryNative: string;
        readonly language: string;
        readonly languageNative: string;
        readonly translations: ILocaleTranslations;
        readonly formats: ILocaleFormats;
    }
    /** Contains the default locale settings. */
    export const DEFAULTS: ILocale;
    export class Locales {
        /** Retrieves the locale information for the current locale. */
        static readonly locale: ILocale;
        /** Retrieves the domain for the current locale. */
        static readonly domain: string;
        /** Retrieves the country code for the active locale. */
        static readonly countryCode: string;
        /** Retrieves the country for the active locale. */
        static readonly country: string;
        /** Retrieves the native country name for the active locale. */
        static readonly countryNative: string;
        /** Retrieves the language for the active locale. */
        static readonly language: string;
        /** Retrieves the language in the native language for the active locale. */
        static readonly languageNative: string;
        /** Retrieves a list of locales. */
        static readonly locales: string[];
        /** Retrieves a list of domains. Each domain contains the locale, language and native language string. */
        static readonly domains: IDomain[];
        /**
         * Verifies if the specified locale is loaded.
         * @param sLocale Specifies the locale identifier.
         * @return Returns `true` if the locale is loaded.
         */
        static isLoaded(sLocale: string): boolean;
        /**
         * Loads the specified locale profiles.
         * @param pLocale Specifies the locale profile (multiple profiles can be supplied).
         * @param bSelect Specifies if the locale needs to be selected as active
         * locale (default is `true`, but only when a single locale is supplied).
         * @return Returns `true` if the locale data is loaded.
         */
        static load(pLocale: ILocale | ILocale[], bSelect?: boolean): boolean;
        /**
         * Retrieves the specified locale.
         * @param sLocale Specifies the locale identifier.
         * @return Returns the locale.
         */
        static get(sLocale?: string): ILocale;
        /**
         * Sets the current locale.
         * @param sLocale Specifies the locale identifier.
         * @return Returns `true` if the locale is set.
         */
        static set(sLocale: string): boolean;
        /**
         * Formats a number by inserting thousands and decimal separators while taking rounding into account.
         * @param nValue Input value as a number or string.
         * @param nPrecision Specifies the precision.
         * @param bThousands Specifies if thousands separators should be inserted.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted number as a string.
         */
        static number(
            nValue: number | string,
            nPrecision?: number,
            bThousands?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a date/time string.
         * @param sFormat Specifies the format to use, using the CLDR date/time formatting style. The following variables are available:
         * - `y` / `yyyy`: Specifies the full 4-digit year;
         * - `yy`: Specifies the 2-digit year;
         * - `M`: Specifies the month number;
         * - `MM`: Specifies the month number with a minimum of 2 digits;
         * - `MMM`: Specifies the month as an abbreviated string which should be supplied through the `pLocalesMonthFormattedAbbreviated`
         * parameter (e.g. `Jan`);
         * - `MMMM`: Specifies the month as a full string which should be supplied through the `pLocalesMonthFormattedWide` parameter (e.g.
         * `January`);
         * - `MMMMM`: Specifies the month as a narrow string which should be supplied through the `pLocalesMonthFormattedNarrow`
         * parameter (e.g. `J`);
         * - `LLL`: Specifies the month as an abbreviated nominative string which should be supplied through the
         * `pLocalesMonthNominativeAbbreviated` parameter (e.g. `Jan`);
         * - `LLLL`: Specifies the month as a full nominative string which should be supplied through the `pLocalesMonthNominativeWide`
         * parameter (e.g. `January`);
         * - `LLLLL`: Specifies the month as a narrow nominative string which should be supplied through the `pLocalesMonthNominativeNarrow`
         * parameter (e.g. `J`);
         * - `d`: Specifies the day of the month;
         * - `dd`: Specifies the day of the month with a minimum of 2 digits;
         * - `E`: Specifies the day of the week;
         * - `EE`: Specifies the day of the week as a string which should be supplied through the `pLocalesWeekdayFormattedShort`
         * parameter (e.g. `Su`);
         * - `EEE`: Specifies the day of the week as an abbreviated string which should be supplied through the
         * `pLocalesWeekdayFormattedAbbreviated` parameter (e.g. `Sun`);
         * - `EEEE`: Specifies the day of the week as a full string which should be supplied through the `pLocalesWeekdayFormattedWide`
         * parameter (e.g. `Sunday`);
         * - `EEEEE`: Specifies the day of the week as a narrow string which should be supplied through the `pLocalesWeekdayFormattedNarrow`
         * parameter (e.g. `S`);
         * - `cc`: Specifies the day of the week as a nominative string which should be supplied through the `pLocalesWeekdayNominativeShort`
         * parameter (e.g. `Su`);
         * - `ccc`: Specifies the day of the week as an abbreviated nominative string which should be supplied through the
         * `pLocalesWeekdayNominativeAbbreviated` parameter (e.g. `Sun`);
         * - `cccc`: Specifies the day of the week as a full nominative string which should be supplied through the
         * `pLocalesWeekdayNominativeWide` parameter (e.g. `Sunday`);
         * - `ccccc`: Specifies the day of the week as a narrow nominative string which should be supplied through the
         * `pLocalesWeekdayNominativeNarrow` parameter (e.g. `S`);
         * - `H`: Specifies the number of hours in 24-hour format;
         * - `HH`: Specifies the number of hours in 24-hour format  with a minimum of 2 digits;
         * - `h`: Specifies the number of hours in 12-hour format;
         * - `hh`: Specifies the number of hours in 12-hour format  with a minimum of 2 digits;
         * - `a`: Specifies the `AM` or `PM` hour suffix;
         * - `m`: Specifies the number of minutes;
         * - `mm`: Specifies the number of minutes with a minimum of 2 digits;
         * - `s`: Specifies the number of seconds;
         * - `ss`: Specifies the number of seconds with a minimum of 2 digits;
         * - `S`: Specifies the number of milliseconds;
         * - `SSS`: Specifies the number of milliseconds with a minimum of 3 digits;
         * @param nTime Specifies the date/time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date string.
         * @see http://cldr.unicode.org/translation/date-time
         */
        static dateTime(
            sFormat: string,
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a full date string.
         * @param nTime Specifies the date to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date string.
         */
        static dateFull(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a long date string.
         * @param nTime Specifies the date to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date string.
         */
        static dateLong(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a medium date string.
         * @param nTime Specifies the date to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date string.
         */
        static dateMedium(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a short date string.
         * @param nTime Specifies the date to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date string.
         */
        static dateShort(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a full time string.
         * @param nTime Specifies the time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted time string.
         */
        static timeFull(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a long time string.
         * @param nTime Specifies the time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted time string.
         */
        static timeLong(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a medium time string.
         * @param nTime Specifies the time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted time string.
         */
        static timeMedium(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a short time string.
         * @param nTime Specifies the time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted time string.
         */
        static timeShort(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a full date/time string.
         * @param nTime Specifies the date/time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date/time string.
         */
        static dateTimeFull(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a long date/time string.
         * @param nTime Specifies the date/time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date/time string.
         */
        static dateTimeLong(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a medium date/time string.
         * @param nTime Specifies the date/time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date/time string.
         */
        static dateTimeMedium(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
        /**
         * Formats a short date/time string.
         * @param nTime Specifies the date/time to format. If this value is not specified `Now` will be used.
         * @param bUTC Specifies if the UTC time needs to be used.
         * @param sLocale Specifies the locale to use.
         * @return Returns the formatted date/time string.
         */
        static dateTimeShort(
            nTime?: number,
            bUTC?: boolean,
            sLocale?: string
        ): string;
    }
}

declare module "@marblecore/l10n/lib/l10n" {
    /**
     * Translates a string using the default language.
     * @param sId Specifies the message identifier or string to translate.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The first argument is referenced with `%1`.
     * @return Returns the translated string.
     */
    export function gettext(sId: string, ...pArguments: string[]): string;
    /**
     * Translates a string using the specified language domain.
     * @param sDomain Specifies the language domain identifier.
     * @param sId Specifies the message identifier or string to translate.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The first argument is referenced with `%1`.
     * @return Returns the translated string.
     */
    export function dgettext(
        sDomain: string,
        sId: string,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a plural string using the default language.
     * @param sId Specifies the message identifier or string to translate.
     * @param sPluralId Specifies the plural message identifier or string to translate.
     * @param nCount Specifies the count for the plural.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The count value `nCount` is automatically included as the first argument (`%1`).
     * @return Returns the translated string.
     */
    export function ngettext(
        sId: string,
        sPluralId: string,
        nCount: number,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a plural string using the specified language domain.
     * @param sDomain Specifies the language domain identifier.
     * @param sId Specifies the message identifier or string to translate.
     * @param sPluralId Specifies the plural message identifier or string to translate.
     * @param nCount Specifies the count for the plural.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The count value `nCount` is automatically included as the first argument (`%1`).
     * @return Returns the translated string.
     */
    export function dngettext(
        sDomain: string,
        sId: string,
        sPluralId: string,
        nCount: number,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a string from a specific context using the default language.
     * @param sContext Specifies the translation context.
     * @param sId Specifies the message identifier or string to translate.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The first argument is referenced with `%1`.
     * @return Returns the translated string.
     */
    export function pgettext(
        sContext: string,
        sId: string,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a string from a specific context using the specified language domain.
     * @param sDomain Specifies the language domain identifier.
     * @param sContext Specifies the translation context.
     * @param sId Specifies the message identifier or string to translate.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The first argument is referenced with `%1`.
     * @return Returns the translated string.
     */
    export function dpgettext(
        sDomain: string,
        sContext: string,
        sId: string,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a plural string using the default language.
     * @param sContext Specifies the translation context.
     * @param sId Specifies the message identifier or string to translate.
     * @param sPluralId Specifies the plural message identifier or string to translate.
     * @param nCount Specifies the count for the plural.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The count value `nCount` is automatically included as the first argument (`%1`).
     * @return Returns the translated string.
     */
    export function npgettext(
        sContext: string,
        sId: string,
        sPluralId: string,
        nCount: number,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a plural string using the specified language domain.
     * @param sDomain Specifies the language domain identifier.
     * @param sContext Specifies the translation context.
     * @param sId Specifies the message identifier or string to translate.
     * @param sPluralId Specifies the plural message identifier or string to translate.
     * @param nCount Specifies the count for the plural.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The count value `nCount` is automatically included as the first argument (`%1`).
     * @return Returns the translated string.
     */
    export function dnpgettext(
        sDomain: string,
        sContext: string,
        sId: string,
        sPluralId: string,
        nCount: number,
        ...pArguments: string[]
    ): string;
    /**
     * Translates a string using the default language (short version for `gettext`).
     * @param sId Specifies the message identifier or string to translate.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed by
     * the argument index `%n`. The first argument is referenced with `%1`.
     * @return Returns the translated string.
     */
    export function _(sId: string, ...pArguments: string[]): string;
    /**
     * Translates a plural string using the default language (short version for `ngettext`).
     * @param sId Specifies the message identifier or string to translate.
     * @param sPluralId Specifies the plural message identifier or string to translate.
     * @param nCount Specifies the count for the plural.
     * @param pArguments Optional string arguments which can be referenced in the translation string using the percent sign followed
     * by the argument index `%n`. The count value `nCount` is automatically included as the first argument (`%1`).
     * @return Returns the translated string.
     */
    export function _n(
        sId: string,
        sPluralId: string,
        nCount: number,
        ...pArguments: string[]
    ): string;
}
